
.. If you created a package, create one automodule per module in the package.

.. automodule:: adafruit_ht16k33.ht16k33
   :members:

.. automodule:: adafruit_ht16k33.bargraph
   :members:

.. automodule:: adafruit_ht16k33.matrix
   :members:

.. automodule:: adafruit_ht16k33.segments
   :members:

.. automodule:: adafruit_ht16k33.animations
   :members:
